package com.kingtom.shengtai.api.controller;

import java.util.List;
import java.util.Map;

import com.kingtom.kirin.app.auth.base.AuthInit;
import com.kingtom.kirin.app.auth.base.Menu;
import com.kingtom.kirin.app.auth.base.Role;
import com.kingtom.kirin.core.common.base.PageInfo;
import com.kingtom.kirin.core.common.base.Result;
import com.kingtom.kirin.core.common.utils.CollectionUtils;
import com.kingtom.kirin.core.common.utils.JsonUtils;
import com.kingtom.shengtai.api.mapper.SrmMapper;
import com.kingtom.shengtai.api.model.SrmCooperateDTO;
import com.kingtom.shengtai.app.srm.model.SrmCooperate;
import com.kingtom.shengtai.app.srm.model.SrmCooperateDO;
import com.kingtom.shengtai.app.srm.service.ISrmCooperateService;
import com.mybatisflex.core.paginate.Page;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.enums.ParameterIn;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * 供应商合作记录表 控制层。
 *
 * @author 86181
 * @since 2023-12-21
 */
@Tag(name = "SrmCooperateController", description = "供应商合作记录表 控制层。")
@RestController
@RequestMapping("/srmCooperates")
@AuthInit(menus = {@Menu(name = "组织管理:供应商管理", otherName = "供应商管理", code = "organization_supplier",
        routeUri = "supplier", orderNum = 25)},
        roles = {@Role(name = "业务管理员", code = "businessAdmin", menuCode = {"organization_supplier"}),
                @Role(name = "供应商", code = "supplier")})
public class SrmCooperateController{

    @Autowired
    private ISrmCooperateService iSrmCooperateService;

    /**
     * 添加 供应商合作记录表。
     *
     * @param dto 供应商合作记录表
     * @return {@code true} 添加成功，{@code false} 添加失败
     */
    @Operation(summary = "添加 供应商合作记录表。", description = "添加 供应商合作记录表。")
    @PostMapping("/")
    public Result<SrmCooperateDTO> save(@RequestBody SrmCooperateDTO dto){
        SrmCooperate convert = SrmMapper.INSTANCE.convert(dto);
        SrmCooperateDO srmCooperateDO = iSrmCooperateService.create(convert);
        return Result.ok(SrmCooperateDTO.convert(srmCooperateDO));
    }

    /**
     * 根据主键删除 供应商合作记录表。
     *
     * @param id 主键
     * @return {@code true} 删除成功，{@code false} 删除失败
     */
    @Parameter(name = "id", description = "主键", in = ParameterIn.PATH, required = true)
    @Operation(summary = "根据主键删除 供应商合作记录表。", description = "根据主键删除 供应商合作记录表。")
    @PostMapping("/{id}/")
    public Result<String> remove(@PathVariable String id){
        iSrmCooperateService.deleteById(id);
        return Result.ok(null);
    }

    /**
     * 根据主键批量删除供应商信息表。
     *
     * @param ids 主键
     * @return {@code true} 删除成功，{@code false} 删除失败
     */
    @Operation(summary = "根据主键批量删除供应商信息表。", description = "根据主键批量删除供应商信息表。")
    @PostMapping("/remove_batch")
    public Result<String> remove(@RequestBody List<String> ids){
        iSrmCooperateService.deleteByIds(ids);
        return Result.ok(null);
    }

    /**
     * 根据主键更新 供应商合作记录表。
     *
     * @param dto 供应商合作记录表
     * @return {@code true} 更新成功，{@code false} 更新失败
     */
    @Operation(summary = "根据主键更新 供应商合作记录表。", description = "根据主键更新 供应商合作记录表。")
    @PostMapping("/{id}/info")
    public Result<SrmCooperateDTO> update(@RequestBody SrmCooperateDTO dto){
        SrmCooperate convert = SrmMapper.INSTANCE.convert(dto);
        SrmCooperateDO srmCooperateDO = iSrmCooperateService.update(convert);
        return Result.ok(SrmCooperateDTO.convert(srmCooperateDO));
    }

    /**
     * 根据 供应商合作记录表主键获取详细信息。
     *
     * @param id 供应商合作记录表主键
     * @return 供应商合作记录表详情
     */
    @Parameter(name = "id", description = "供应商合作记录表主键", in = ParameterIn.PATH, required = true)
    @Operation(summary = "根据 供应商合作记录表主键获取详细信息。",
            description = "根据 供应商合作记录表主键获取详细信息。")
    @GetMapping("/{id}/info")
    public Result<SrmCooperateDTO> getInfo(@PathVariable String id){
        SrmCooperateDO srmCooperateDO = iSrmCooperateService.findById(id);
        return Result.ok(SrmCooperateDTO.convert(srmCooperateDO));
    }

    /**
     * 分页查询 供应商合作记录表。
     *
     * @param query    查询条件
     * @param pageNum  当前页码
     * @param pageSize 每页数量
     * @return 分页对象
     */
    @Operation(summary = "分页查询 供应商合作记录表。", description = "分页查询 供应商合作记录表。")
    @GetMapping("/page")
    public Result<PageInfo<SrmCooperateDTO>> page(String query, Integer pageNum, Integer pageSize){
        Map<String, Object> object = JsonUtils.toObject(query, Map.class);
        String search = object.get("search") == null ? null : object.get("search").toString();
        String supplierId = object.get("supplierId") instanceof String ? object.get("supplierId").toString() : null;
        Page<SrmCooperateDO> page = iSrmCooperateService.page(search, supplierId, pageNum, pageSize);
        return Result.ok(CollectionUtils.convertPage(page, SrmCooperateDTO::convert));
    }

}
