package com.kingtom.shengtai.app.base.session;

import java.util.List;

import com.kingtom.kirin.app.auth.model.AuthRole;
import com.kingtom.kirin.app.auth.service.IAuthService;
import com.kingtom.kirin.app.security.base.ISessionDataLoader;
import com.kingtom.kirin.app.security.base.SessionData;
import com.kingtom.kirin.app.security.service.ISecurityContainerService;
import com.kingtom.kirin.core.common.CommonConst;
import jakarta.annotation.PostConstruct;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

/**
 * 应用模块名称</p>
 * 代码描述</p>
 * Copyright: Copyright (C) 2023 , Inc. All rights reserved. <p>
 * Company: 成都诚唐科技有限责任公司</p>
 *
 * @author wany
 * @since 2023/12/26
 */
@Component
public class SessionLoader implements ISessionDataLoader{

    @Autowired
    private ISecurityContainerService container;

    @Autowired
    private IAuthService authService;

    @PostConstruct
    public void init(){
        container.registerSessionLoader(this);
    }

    @Override
    public int getOrder(){
        return CommonConst.INT_100;
    }

    @Override
    public void onLoad(SessionData data){
        List<AuthRole> rolesByUserId = authService.findRolesByUserId(data.getUserId(), data.getSysId());
        data.putAttr("BusinessRole", null);
        if(rolesByUserId.stream().anyMatch(e -> e.getCode().equals("supplier"))){
            data.putAttr("BusinessRole", "supplier");
        }
        if(rolesByUserId.stream().anyMatch(e -> e.getCode().equals("businessAdmin"))){
            data.putAttr("BusinessRole", "businessAdmin");
        }
        ISessionDataLoader.super.onLoad(data);
    }

}
